@@ -1,12 +1,11 @@
 import logging
 from typing import Union
 
-from twisted.internet.defer import Deferred, inlineCallbacks
-
 from peek_plugin_graphdb._private.client.controller.SegmentCacheController import \
     SegmentCacheController
 from peek_plugin_graphdb._private.tuples.SegmentIndexUpdateDateTuple import \
     SegmentIndexUpdateDateTuple
+from twisted.internet.defer import Deferred, inlineCallbacks
 from vortex.Payload import Payload
 from vortex.TupleSelector import TupleSelector
 from vortex.handler.TupleDataObservableHandler import TuplesProviderABC
@@ -23,8 +22,8 @@ class SegmentUpdateDateTupleProvider(TuplesProviderABC):
                       tupleSelector: TupleSelector) -> Union[Deferred, bytes]:
         tuple_ = SegmentIndexUpdateDateTuple()
         tuple_.updateDateByChunkKey = {
-            key:self._cacheHandler.segmentChunk(key).lastUpdate
-            for key in self._cacheHandler.segmentKeys()
+            key: self._cacheHandler.encodedChunk(key).lastUpdate
+            for key in self._cacheHandler.encodedChunkKeys()
         }
         payload = Payload(filt, tuples=[tuple_])
         payloadEnvelope = yield payload.makePayloadEnvelopeDefer()
